#include <Adafruit_NeoPixel.h>

#define LEDPIN 4        // Arduino-Pin für Signalleitung zu LEDs

const int leds = 50;    // Anzahl der LEDs
const int buzzer = 5;   // Arduino-Pin für optionalen 5V Piezo-Buzzer
int sicherheit = 5;     // Sicherheitsabstand (wird zum Messwert addiert) in Zentimeter
long aktiveleds = 0;    // Variable für Anzahl der aktiven LEDs
const int trig = 3;     // Arduino-Pin für Sonarmodul TRIG-Anschluss
const int echo = 2;     // Arduino-Pin für Sonarmodul ECHO-Anschluss
long dauer;             // Variable für die vom Sonarmodul gemessene Echo-Zeit
int abstand = 0;        // Sicherheitsabstand (wird zum Messwert addiert) in Zentimeter

// NeoPixel LEDs definieren und Farbwert festlegen
Adafruit_NeoPixel pixels = Adafruit_NeoPixel(leds, LEDPIN, NEO_GRB + NEO_KHZ800);
int redColor;  
int greenColor;
int blueColor;
int delayval = 50;      // Verzögerungswert in Millisekunden zur zeitlichen Glättung der Anzeige

void setup() {
Serial.begin(115200);   // Serielle Verbindung aktivieren (Datenrate = 115200 Bit pro Sekunde)
// Kann genutzt werden, um im "Seriellen Monitor" in der Arduino IDE über USB Statusmeldungen abzurufen.
pinMode(trig, OUTPUT);  // Arduino-Pin für Sonarmodul TRIG-Anschluss als Ausgang
pinMode(echo, INPUT);   // Arduino-Pin für Sonarmodul ECHO-Anschlus als Eingang
pinMode(buzzer, OUTPUT);  // Arduino-Pin für Buzzer als Ausgang
    
pixels.begin();
pixels.show();          // LED-Kommunikation starten und alle LEDs ausschalten
delay(200);  
}

void loop() {
// trig-Anschluss aktivieren
digitalWrite(trig, LOW);
delayMicroseconds(2);
// trig-Anschluss für 10 Mikrosekunden aktivieren
digitalWrite(trig, HIGH);
delayMicroseconds(10);
digitalWrite(trig, LOW);
// echo-Anschluss lesen, gibt die Reisezeit der Ultraschallwelle in Mikrosekunden zurück
dauer = pulseIn(echo, HIGH);


// Berechnung der Distanz aus dem gemessenen Echo-Zeitwert des Sonarmoduls. 
// Gemessene Dauer des Schallsignals (hin und zurück) in Mikrosekunden * Schallgeschwindigkeit 0,0034 cm / Mikrosekunde
// Ergibt: Abstand in CM
abstand = (dauer * 0.034 / 2) - sicherheit;
Serial.print("Abstand (inkl. Sicherheit): ");    
Serial.println(abstand);    
        
LEDFarbe();   // Funktion Farbe einstellen (siehe unten)
aktiveleds = leds - (abstand * 0.01 * leds);   // Anzahl der LEDs berechnen (Range: 100 bis 0 Zentimeter)
pixels.clear();
  
for(int i=0;i<=aktiveleds;i++){
pixels.setPixelColor(i, pixels.Color(redColor, greenColor, blueColor));
}
pixels.show();
delay(delayval);
}


void LEDFarbe(){
// Farbwert der LEDs festlegen.
// 50 bis 100 cm -> Grün
// 30 bis 49 cm -> Gelb
// 0 bis 29 cm -> Rot
switch (abstand)
{
case 50 ... 100:
  redColor = 0;
  greenColor = 50;
  blueColor = 0;
  break;
case 30 ... 49:
  redColor = 50;
  greenColor = 50;
  blueColor = 0;
  break;
case 0 ... 29:
  redColor = 50;
  greenColor = 0;
  blueColor = 0;
  break;
default:
  redColor = 50;
  greenColor = 0;
  blueColor = 0;
  break;
}
}
  
////////////////////////
